@@ -3,7 +3,7 @@ from .docstring_parsing import DocStringInfo, Arg
 from .enabling import all_disabled
 from .interface import (Contract, ContractSyntaxError, Where,
                         ContractException, ContractNotRespected,
-                        describe_value)
+                        describe_value, MissingContract)
 from .library import (identifier_expression, Extension, CheckCallable,
                       SeparateContext)
 from .library.extensions import CheckCallableWithSelf
@@ -167,7 +167,7 @@ def contract_decorator(*arg, **kwargs):
                 # Erase the stack
                 raise ContractSyntaxError(e.error, e.where)
         else:
-            msg = ('I expect that  contracts() is called with '
+            msg = ('I expect that contracts() is called with '
                     'only keyword arguments (passed: %r)' % arg)
             raise ContractException(msg)
     else:
@@ -185,12 +185,12 @@ def contract_decorator(*arg, **kwargs):
         return tmp_wrap
 
 
-def contracts_decorate(function, modify_docstring=True, **kwargs):
+def contracts_decorate(function_, modify_docstring=True, **kwargs):
     ''' An explicit way to decorate a given function.
         The decorator :py:func:`decorate` calls this function internally. 
     '''
 
-    all_args = get_all_arg_names(function)
+    all_args = get_all_arg_names(function_)
 
     if kwargs:
 
@@ -205,7 +205,7 @@ def contracts_decorate(function, modify_docstring=True, **kwargs):
 
     else:
         # Py3k: check if there are annotations
-        annotations = get_annotations(function)
+        annotations = get_annotations(function_)
 
         if annotations:
             #print(annotations)
@@ -218,13 +218,13 @@ def contracts_decorate(function, modify_docstring=True, **kwargs):
             accepts_dict = annotations
         else:
             # Last resort: get types from documentation string.
-            if function.__doc__ is None:
+            if function_.__doc__ is None:
                 # XXX: change name
                 raise ContractException(
                                 'You did not specify a contract, nor I can '
-                                        'find a docstring for %r.' % function)
+                                        'find a docstring for %r.' % function_)
 
-            accepts_dict, returns = parse_contracts_from_docstring(function)
+            accepts_dict, returns = parse_contracts_from_docstring(function_)
 
             if not accepts_dict and not returns:
                 raise ContractException('No contract specified in docstring.')
@@ -239,16 +239,16 @@ def contracts_decorate(function, modify_docstring=True, **kwargs):
 
     # TODO: add classname if bound method
     nice_function_display = ('%s() in %s' %
-                             (function.__name__, function.__module__))
+                             (function_.__name__, function_.__module__))
 
     is_bound_method = 'self' in all_args
 
     def contracts_checker(unused, *args, **kwargs):
         do_checks = not all_disabled()
         if not do_checks:
-            return function(*args, **kwargs)
+            return function_(*args, **kwargs)
 
-        bound = getcallargs(function, *args, **kwargs)
+        bound = getcallargs(function_, *args, **kwargs)
 
         try:
             context = {}
@@ -266,7 +266,7 @@ def contracts_decorate(function, modify_docstring=True, **kwargs):
             e.error = msg + e.error
             raise e
 
-        result = function(*args, **kwargs)
+        result = function_(*args, **kwargs)
 
         if returns_parsed is not None:
             try:
@@ -285,8 +285,8 @@ def contracts_decorate(function, modify_docstring=True, **kwargs):
         def write_contract_as_rst(c):
             return '``%s``' % c
 
-        if function.__doc__ is not None:
-            docs = DocStringInfo.parse(function.__doc__)
+        if function_.__doc__ is not None:
+            docs = DocStringInfo.parse(function_.__doc__)
         else:
             docs = DocStringInfo("")
         for param in accepts_parsed:
@@ -305,19 +305,19 @@ def contracts_decorate(function, modify_docstring=True, **kwargs):
         new_docs = docs.__str__()
 
     else:
-        new_docs = function.__doc__
+        new_docs = function_.__doc__
 
     # XXX: why doesn't this work?
-    contracts_checker.__name__ = 'checker-for-%s' % function.__name__
-    contracts_checker.__module__ = function.__module__
+    contracts_checker.__name__ = 'checker-for-%s' % function_.__name__
+    contracts_checker.__module__ = function_.__module__
 
     # TODO: is using functools.wraps better?
     from decorator import decorator #@UnresolvedImport
-    wrapper = decorator(contracts_checker, function)
+    wrapper = decorator(contracts_checker, function_)
 
     wrapper.__doc__ = new_docs
-    wrapper.__name__ = function.__name__
-    wrapper.__module__ = function.__module__
+    wrapper.__name__ = function_.__name__
+    wrapper.__module__ = function_.__module__
 
     return wrapper
 
@@ -343,10 +343,13 @@ def parse_contracts_from_docstring(function):
 
     def remove_quotes(x):
         ''' Removes the double back-tick quotes if present. '''
+        if x is None:
+            return None
         if x.startswith('``') and x.endswith('``') and len(x) > 3:
             return x[2:-2]
         elif x.startswith('``') or x.endswith('``'):
-            raise ContractException('Malformed quoting in string %r.' % x)
+            msg = 'Malformed quoting in string %r.' % x
+            raise ContractException(msg)
         else:
             return x
 
@@ -360,6 +363,21 @@ def parse_contracts_from_docstring(function):
     name2type = dict([(name, remove_quotes(params[name].type))
                        for name in params])
 
+    # Check the ones that do not have contracts specified
+    nullparams = [name for name in params if params[name].type is None]
+    if nullparams:
+        msg = ('The parameter(s) %r in this docstring have no type statement.'
+                % (",".join(nullparams)))
+        msg += """
+
+Note: you can use the asterisk if you do not care about assigning
+a contract to a certain parameter:
+
+    :param x: 
+    :type x: *
+"""
+        raise MissingContract(msg)
+
     # Let's look at the parameters:
     all_args = get_all_arg_names(function)
 
@@ -367,8 +385,8 @@ def parse_contracts_from_docstring(function):
     for name in name2type:
         if not name in all_args:
             msg = ('A contract was specified for argument %r which I cannot'
-                   ' find in my list of arguments (%s)' %
-                    (name, ", ".join(all_args)))
+                   ' find in my list of arguments (%r)' %
+                    (name, all_args))
             raise ContractException(msg)
 
     if len(name2type) != len(all_args): # pragma: no cover
